@@ -6,7 +6,7 @@ import math
 import numpy as np
 
 from .schemas import Location, Point, Overpass, PassType
-from .constants import RAD2DEG
+from .constants import RAD2DEG, DAY_S
 from .rotations import ecef2sez
 from .topocentric import site_ECEF
 from .timefn import jday2datetime
@@ -40,6 +40,11 @@ class SunPredictData:
     __slots__ = ['rECEF']
     rECEF: np.ndarray
 
+    def __getitem__(self, slc):
+        return SunPredictData(
+            rECEF=self.rECEF[:, slc]
+        )
+
 
 @dataclass
 class SatPredictData:
@@ -48,6 +53,13 @@ class SatPredictData:
     rECEF: np.ndarray         # dtype np.float32
     illuminated: np.ndarray   # dtype bool
 
+    def __getitem__(self, slc):
+        return SatPredictData(
+            id=self.id,
+            rECEF=self.rECEF[:, slc],
+            illuminated=self.illuminated[slc]
+        )
+
 
 class RhoVectorBase:
     pass
@@ -63,6 +75,7 @@ class RhoVector():
         self.sat = sat
         self.location = location
         self.sun = sun
+        self.dt_seconds = int(round((jd[1] - jd[0]) * DAY_S, 0))
         
         if sun is not None:
             assert sat.illuminated is not None
@@ -97,7 +110,7 @@ class RhoVector():
         return np.arcsin(self.rSEZ[2] / self.rng) * RAD2DEG
 
     @cached_property
-    def el(self):
+    def el(self) -> np.ndarray:
         return self._el()
 
     def az(self, idx):
@@ -114,9 +127,9 @@ class RhoVector():
     def point(self, idx):
         return Point.construct(
             datetime=jday2datetime(self.jd[idx]),
-            azimuth=round(self.az(idx), 3),
-            elevation=round(self.el[idx], 3),
-            range=round(self.rng[idx], 4)
+            azimuth=round(self.az(idx), 2),
+            elevation=round(self.el[idx], 2),
+            range=round(self.rng[idx], 3)
         )
 
     def _start_end_index(self, x):
@@ -138,12 +151,15 @@ class RhoVector():
     #     # find phase angle between observer -- satellite -- sun
     #     gamma = self.el[idx] - sun_el[idx]
 
-    def find_overpasses(self, min_elevation=10, store_sat_id=False, sunset_el=-6):
+    def find_overpasses(self, min_elevation: float = 10.0, store_sat_id: bool = False, sunset_el: float = -6.0, visible_only: bool = False):
         start_idx, end_idx = self._start_end_index(self.el - min_elevation)
         num_overpasses = min(start_idx.size, end_idx.size)       # Iterate over start/end indecies and gather inbetween indecies
         if start_idx.size < end_idx.size:
             end_idx = end_idx[1:]
-        sat_overpasses = [None] * num_overpasses
+        if not visible_only:
+            sat_overpasses = [None] * num_overpasses
+        else:
+            sat_overpasses = []
         for j in range(num_overpasses):
             # Store indecies of overpasses in a list
             idx0 = start_idx[j]
@@ -167,12 +183,12 @@ class RhoVector():
                     # get satellite illumination values for this overpass
                     sat_visible = (self.sat.illuminated[idx0:idxf+1] * site_in_sunset)
                     if np.any(sat_visible):
+                        passtype = PassType.visible # site in night, sat is illuminated
                         sat_visible_idx = np.nonzero(sat_visible)[0]
                         sat_visible_start_idx = sat_visible_idx.min()
                         sat_visible_end_idx = sat_visible_idx.max()
                         vis_start_pt = self.point(idx0 + sat_visible_start_idx)
                         vis_end_pt = self.point(idx0 + sat_visible_end_idx)
-                        passtype = PassType.visible # site in night, sat is illuminated
                         brightness_idx = np.argmax(self.el[idx0 + sat_visible_start_idx: idx0 + sat_visible_end_idx + 1])
                         sat_rho = self.rECEF[:, idx0 + sat_visible_start_idx + brightness_idx]
                         sat_rng = self.rng[idx0 + sat_visible_start_idx + brightness_idx]
@@ -188,6 +204,10 @@ class RhoVector():
                         passtype = PassType.unlit  # nighttime, not illuminated (radio night)
             else:
                 passtype = None
+
+            if visible_only and passtype != PassType.visible:
+                continue
+
             overpass_dict = {
                 'start_pt': start_pt,
                 'max_pt': max_pt,
@@ -198,8 +218,11 @@ class RhoVector():
             if (passtype is not None) and (passtype == PassType.visible):
                 overpass_dict['vis_start_pt'] = vis_start_pt
                 overpass_dict['vis_end_pt'] = vis_end_pt
-                overpass_dict['brightness'] = round(brightness, 3)
+                overpass_dict['brightness'] = round(brightness, 2)
             overpass_dict['type'] = passtype
             overpass = Overpass.construct(**overpass_dict)
-            sat_overpasses[j] = overpass
+            if not visible_only:
+                sat_overpasses[j] = overpass
+            else:
+                sat_overpasses.append(overpass)
         return sat_overpasses
\ No newline at end of file
