@@ -1,5 +1,5 @@
 from datetime import datetime, timedelta
-from typing import List
+from typing import List, Callable
 import time
 
 from astropy.time import Time
@@ -8,12 +8,19 @@ from numpy import ndarray
 from .solar import compute_sun_data
 from .propagate import compute_satellite_data
 from .timefn import julian_date_array_from_date
-from .schemas import Overpass, Location
+from .schemas import Overpass, Location, Satellite
 from .models import Sun, RhoVector, Sat
-from .utils import get_TLE
+from .tle import get_TLE
 
 
-def find_overpasses(jd: ndarray, location: Location, sats: List[Sat], sun: Sun, min_elevation: float = 10) -> List[Overpass]:
+def find_overpasses(
+    jd: ndarray, 
+    location: Location, 
+    sats: List[Sat], 
+    sun: Sun, 
+    min_elevation: float = 10.0, 
+    visible_only: bool =False
+) -> List[Overpass]:
     """
     Real-time computation for finding satellite overpasses of a topographic location.
     Can support multiple satellites over a single location
@@ -22,12 +29,24 @@ def find_overpasses(jd: ndarray, location: Location, sats: List[Sat], sun: Sun,
     overpasses = []
     for sat in sats:
         rho = RhoVector(jd, sat, location, sun)
-        sat_overpasses = rho.find_overpasses(min_elevation, store_sat_id)
+        sat_overpasses = rho.find_overpasses(min_elevation, store_sat_id, visible_only=visible_only)
         overpasses += sat_overpasses
     return overpasses
 
 
-def predict(location, satellite, date_start=None, date_end=None, dt_seconds=1, min_elevation=None, cache=None, verbose=False, store_sat_id=False, print_fn=print):
+def predict(
+    location: Location,
+    satellite: Satellite,
+    date_start: datetime = None,
+    date_end: datetime = None,
+    dt_seconds: int = 1,
+    min_elevation: float = 10.0,
+    cache: 'Cache' = None,
+    verbose: bool = False, 
+    store_sat_id: bool = False, 
+    print_fn: Callable = print, 
+    visible_only: bool = False
+):
     """
     Full prediction algorithm:
       1. Download TLE data
@@ -81,7 +100,7 @@ def predict(location, satellite, date_start=None, date_end=None, dt_seconds=1, m
 
     if verbose:
         print_fn('Predict overpasses... ')
-    overpasses = find_overpasses(jd, location, [sat], sun, min_elevation)
+    overpasses = find_overpasses(jd, location, [sat], sun, min_elevation, visible_only=visible_only)
     return overpasses
 
 
